@@ -21,9 +21,17 @@
  */
 
 #include "config.h"
-#include "gurifuncs.h"
-#include "string.h"
 
+#include "gurifuncs.h"
+
+#include <glib/gstrfuncs.h>
+#include <glib/gmessages.h>
+#include <glib/gstring.h>
+#include <glib/gmem.h>
+
+#include <string.h>
+
+#include "config.h"
 #include "galias.h"
 
 /**
@@ -208,7 +216,7 @@ g_uri_parse_scheme (const char  *uri)
  * g_uri_escape_string:
  * @unescaped: the unescaped input string.
  * @reserved_chars_allowed: a string of reserved characters that are
- *      allowed to be used.
+ *      allowed to be used, or %NULL.
  * @allow_utf8: %TRUE if the result can include UTF-8 characters.
  * 
  * Escapes a string for use in a URI.
