@@ -20,9 +20,12 @@
  * Author: Ryan Lortie <desrt@desrt.ca>
  */
 
+#include "config.h"
+
 #include "gvarianttype.h"
 
 #include <glib/gtestutils.h>
+#include <glib/gstrfuncs.h>
 
 #include <string.h>
 
@@ -479,29 +482,6 @@
  * </refsect2>
  */
 
-/**
- * GVariantType:
- *
- * A type in the GVariant type system.
- *
- * Two types may not be compared by value; use g_variant_type_equal() or
- * g_variant_type_is_subtype().  May be copied using
- * g_variant_type_copy() and freed using g_variant_type_free().
- **/
-
-/**
- * G_VARIANT_TYPE:
- * @type_string: a well-formed #GVariantType type string
- *
- * Converts a string to a const #GVariantType.  Depending on the
- * current debugging level, this function may perform a runtime check
- * to ensure that @string is a valid GVariant type string.
- *
- * It is always a programmer error to use this macro with an invalid
- * type string.
- *
- * Since 2.24
- **/
 
 static gboolean
 g_variant_type_check (const GVariantType *type)
@@ -603,7 +583,7 @@ g_variant_type_string_scan (const gchar  *string,
 gboolean
 g_variant_type_string_is_valid (const gchar *type_string)
 {
-  gchar *endptr;
+  const gchar *endptr;
 
   g_return_val_if_fail (type_string != NULL, FALSE);
 
@@ -671,6 +651,8 @@ g_variant_type_copy (const GVariantType *type)
  *
  * It is a programmer error to call this function with an invalid type
  * string.  Use g_variant_type_string_is_valid() if you are unsure.
+ *
+ * Since: 2.24
  */
 GVariantType *
 g_variant_type_new (const gchar *type_string)
@@ -977,6 +959,23 @@ g_variant_type_is_dict_entry (const GVariantType *type)
   return g_variant_type_peek_string (type)[0] == '{';
 }
 
+/**
+ * g_variant_type_is_variant:
+ * @type: a #GVariantType
+ * @returns: %TRUE if @type is the variant type
+ *
+ * Determines if the given @type is the variant type.
+ *
+ * Since 2.24
+ **/
+gboolean
+g_variant_type_is_variant (const GVariantType *type)
+{
+  g_return_val_if_fail (g_variant_type_check (type), FALSE);
+
+  return g_variant_type_peek_string (type)[0] == 'v';
+}
+
 /**
  * g_variant_type_hash:
  * @type: a #GVariantType
